@@ -84,10 +84,6 @@ static gboolean libgnomeui_goption_disable_crash_dialog (const gchar *option_nam
 							 const gchar *value,
 							 gpointer data,
 							 GError **error);
-static gboolean libgnomeui_goption_display (const gchar *option_name,
-					    const gchar *value,
-					    gpointer data,
-					    GError **error);
 static void libgnomeui_init_pass	(const GnomeModuleInfo *mod_info);
 static void libgnomeui_class_init	(GnomeProgramClass *klass,
 					 const GnomeModuleInfo *mod_info);
@@ -136,9 +132,25 @@ static GOptionEntry libgnomeui_goptions[] = {
 	{ "disable-crash-dialog", '\0', G_OPTION_FLAG_NO_ARG,
 	  G_OPTION_ARG_CALLBACK, libgnomeui_goption_disable_crash_dialog,
 	  N_("Disable Crash Dialog"), NULL },
+	/* --display is already handled by gtk+ */
 	{ NULL }
 };
 
+static GOptionGroup *
+libgnomeui_get_goption_group (void)
+{
+	GOptionGroup *option_group;
+
+	option_group = g_option_group_new ("gnome-ui",
+					   N_("GNOME GUI Library"),
+					   N_("Show GNOME GUI options"),
+					   NULL, NULL);
+	g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
+	g_option_group_add_entries(option_group, libgnomeui_goptions);
+
+	return option_group;
+}
+
 const GnomeModuleInfo *
 libgnomeui_module_info_get (void)
 {
@@ -151,15 +163,7 @@ libgnomeui_module_info_get (void)
 		NULL, NULL
 	};
 
-	GOptionGroup * option_group;
-	option_group = g_option_group_new ("gnome-ui",
-					   N_("GNOME GUI Library"),
-					   N_("Show GNOME GUI options"),
-					   NULL, NULL);
-	g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
-	g_option_group_add_entries(option_group, libgnomeui_goptions);
-
-	module_info.expansion1 = (gpointer) option_group;
+	module_info.get_goption_group_func = libgnomeui_get_goption_group;
 
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[6];
@@ -522,8 +526,10 @@ event_sounds_changed_cb (GConfClient* client, guint cnxn_id, GConfEntry *entry,
                                 gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
 
         if (new_use_event_sounds && !use_event_sounds) {
+                GDK_THREADS_ENTER();
                 initialize_gtk_signal_relay ();
                 initialize_gnome_signal_relay ();
+                GDK_THREADS_LEAVE();
 	}
 
         use_event_sounds = new_use_event_sounds;
